You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openjpa.apache.org by st...@apache.org on 2019/01/10 12:31:27 UTC

[openjpa] 03/03: OPENJPA-2761 properly handle javax.sql.Types.SQLXML

This is an automated email from the ASF dual-hosted git repository.

struberg pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/openjpa.git

commit aae0a95f6c8f38e0df18e5f538761ee502d9eb08
Author: Mark Struberg <st...@apache.org>
AuthorDate: Thu Jan 10 13:29:49 2019 +0100

    OPENJPA-2761 properly handle javax.sql.Types.SQLXML
---
 .../src/main/java/org/apache/openjpa/jdbc/schema/Column.java         | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/openjpa-jdbc/src/main/java/org/apache/openjpa/jdbc/schema/Column.java b/openjpa-jdbc/src/main/java/org/apache/openjpa/jdbc/schema/Column.java
index 65ac62d..35b02a6 100644
--- a/openjpa-jdbc/src/main/java/org/apache/openjpa/jdbc/schema/Column.java
+++ b/openjpa-jdbc/src/main/java/org/apache/openjpa/jdbc/schema/Column.java
@@ -766,7 +766,8 @@ public class Column extends ReferenceCounter {
                     default:
                         return false;
                 }
-            case 2007:  // Oracle-defined opaque type code for XMLType
+            case Types.SQLXML:  // All XML Types
+            case 2007:          // Oracle-defined opaque type code for XMLType treated the same way
                 switch (type) {
                     case Types.CHAR:
                     case Types.LONGVARCHAR:
@@ -778,6 +779,8 @@ public class Column extends ReferenceCounter {
                          return false;
                 }
 
+
+
             default:
                 return type == getType();
         }